@@ -33,7 +33,7 @@ import os
 import sys
 import traceback
 
-VERSION='0.27'
+VERSION='0.28'
 
 def lint(args):
     logger = getLogger(__name__)
@@ -67,7 +67,9 @@ def lint(args):
         logger.debug(u'"{}" is a directory.'.format(file_path))
         source_dir = ReVIEWProject.guess_source_dir(file_path)
         logger.debug(u'source_dir: {}'.format(source_dir))
-
+        if not source_dir:
+            logger.error(u'Failed to detect source_dir')
+            return
         project = ReVIEWProject(source_dir, logger=logger)
         project.parse_source_files()
         try:
